<?php

/**
 * Author: Daniel Alonso & Alberto Alvarez
 * Web: http://www.informax.es
 * Email: informax@informax.es
 * Created: 2009-02-26
 * 
 * File: disccountmassive.php
 * Provides:
 *  Disccount to all product in one task.
 * 
 */
class massivediscount extends Module {
    /* @var boolean error */

    protected $error = false;

    function __construct() {
        Tools::addJs(array($this->_path . 'js/massivediscount.js'));
        $this->name = 'massivediscount';
        $this->tab = 'Products';
        $this->version = '1.0';

        parent::__construct();

        /* The parent construct is required for translations */
        $this->page = basename(__FILE__, '.php');
        $this->displayName = $this->l('Rebajas Masiva');
        $this->description = $this->l('Rebaja todos tus productos de una sola vez');
        $this->confirmUninstall = $this->l('Seguro que me quieres borrar?');
    }

    function install($try_again=true) {
        if (!parent::install()) {
            return false;
        }
        $sql = 'CREATE TABLE IF NOT EXISTS '._DB_PREFIX_.'massiveDisccount (
                `id` INT(10) NOT NULL AUTO_INCREMENT,
                `idUsuario` INT(10) NULL DEFAULT NULL,
                `idElemento` INT(10) NULL DEFAULT NULL,
                `tipoElemento` INT(10) NULL DEFAULT NULL,
                `tipoActualizacion` INT(10) NULL DEFAULT NULL,
                `valor` DOUBLE NULL DEFAULT NULL,
                `fecha` DATETIME NULL DEFAULT NULL,
                PRIMARY KEY (`id`)
        )ENGINE='._MYSQL_ENGINE_.' default CHARSET=utf8';
        if (!Db::getInstance()->Execute($sql))
        {
        return false;
        }
        $sql = 'CREATE TABLE IF NOT EXISTS '._DB_PREFIX_.'massiveDisccount_product (
                `id` INT(10) NOT NULL AUTO_INCREMENT,
                `idUsuario` INT(10) NULL DEFAULT NULL,
                `idProducto` INT(10) NULL DEFAULT NULL,
                `precioAntiguo` DOUBLE NULL DEFAULT NULL,
                `precioNuevo` DOUBLE NULL DEFAULT NULL,
                `fecha` DATETIME NULL DEFAULT NULL,
                PRIMARY KEY (`id`)
            )ENGINE='._MYSQL_ENGINE_.' default CHARSET=utf8';
        if(!Db::getInstance()->Execute($sql))
         {
          return false;
        }
        return (Configuration::updateValue('PS_MASSIVEDISCOUNT_TITLE', array('1' => 'Actualizacion Masiva')));
    }

    function uninstall() {
        if (parent::uninstall() == false)
            return false;
        $sql = 'DROP table '._DB_PREFIX_.'massiveDisccount';
        if (!Db::getInstance()->Execute($sql)) {
            return false;
        }
        $sql = 'DROP table '._DB_PREFIX_.'massiveDisccount_product';
        if (!Db::getInstance()->Execute($sql)) {
            return false;
        }
        return (Configuration::deleteByName('PS_MASSIVEDISCOUNT_TITLE'));
        
    }

    function getConfig() {

        //$weight_units = strtolower(Configuration::get('PS_WEIGHT_UNIT'));
        $main_product_fields = array(
            "price" => array(
                "db_field" => "price",
                "friendly" => "Price",
                "prefix" => '$',
            )
        );
        return $main_product_fields;
    }

    function updateProducts() {
        $product_settings = $_POST['mup'];

        if (!is_array($product_settings)) {
            return false;
        }

        $main_fields = $this->getConfig();

        foreach ($product_settings as $product_id => $data) {
            $product_id = (int) $product_id;
            if (!$product_id)
                continue;
            $sql = "UPDATE " . _DB_PREFIX_ . "product SET date_upd = NOW() ";
            $do_update = false;
            // we're updating the product id. check and update the main fields.
            foreach ($main_fields as $field) {
                $update_value = trim(pSQL($data[$field['db_field']]));
                if ($update_value) {
                    // we've found a main field to update!
                    $do_update = true;
                    $sql .= ", `" . $field['db_field'] . "` = '$update_value' ";
                }
            }
            if ($do_update) {
                $sql .= " WHERE `id_product` = '$product_id' LIMIT 1";
                //echo $sql ." <br>\n";
                if (!Db::getInstance()->Execute($sql)) {
                    // yer yer i know - dodgey - but this should never happen, all input is sanatised.
                    // a "just in case" so we dont go and bork all our products if there's a coding error.
                    $this->_errors[] = Tools::displayError('Se ha producido un error');
                    exit;
                }
            }
            // now we have to check the product features! trickeyness..
            // we grab a list of their current features, if any...
            $product_features = Product::getFeaturesStatic($product_id);
            //print_r($product_features);
            $new_features = array();
            $do_feature_update = false;
            if (isset($data['ff']) && is_array($data['ff'])) {
                foreach ($data['ff'] as $feature_id => $feature_value) {
                    $update_value = trim(pSQL($feature_value));
                    if ($update_value) {
                        //YEY! we can update this products feature value... 
                        $do_feature_update = true;
                        $new_features[$feature_id] = $update_value;
                    }
                }
            }
            $language_id = 1;
            //print_r($new_features);
            if ($do_feature_update) {
                $product = new Product($product_id);
                $product->deleteFeatures();
                foreach ($new_features as $feature_id => $feature_value) {
                    // add our new custom feature:
                    //echo "Adding $feature_id as $feature_value <br>\n";
                    $id_value = $product->addFeaturesToDB($feature_id, 0, true, $language_id);
                    $product->addFeaturesCustomToDB($id_value, $language_id, $feature_value);
                }
            }
        }

        return true;
    }

    function getContent() {

        global $cookie;
        $this->_html = '<h2>' . $this->displayName . '</h2>';
//        Tools::addJS($this->_path.'js/massivediscount.js');
//        Tools::addCSS($this->_path.'css/massivediscount.css');
        echo '<link type="text/css" rel="stylesheet" href="' . _MODULE_DIR_ . $this->name . '/css/massivediscount.css">';
        echo '<script type="text/javascript" src="' . _MODULE_DIR_ . $this->name . '/js/massivediscount.js" ></script>';
        /* Update the settings */
        if (isset($_POST['mu_doupdate'])) {
            if (!$this->updateProducts())
                $this->_html .= $this->displayError($this->l('An error occurred during product updating, please try saving again.'));
            else
                $this->_html .= $this->displayConfirmation($this->l('Your products have been successfully updated!'));
        }

        $this->_html .= '
            <div id="mostrarErrores"></div>
	 	<fieldset class="massiveDiscount">
			<legend><img src="' . $this->_path . 'add.png" alt="" title="" /> ' . $this->l('Actualizacion Masiva de Articulos') . '</legend>
			<form method="post" action="' . $_SERVER['REQUEST_URI'] . '">';

        $sql = 'SELECT *
				FROM `' . _DB_PREFIX_ . 'feature` f
				LEFT JOIN `' . _DB_PREFIX_ . 'feature_lang` fl ON ( f.`id_feature` = fl.`id_feature` AND fl.`id_lang` = '.$cookie->id_lang.')';
        $feature_results = Db::getInstance()->ExecuteS($sql);


        // all products
        $sql = 'SELECT *
				FROM `' . _DB_PREFIX_ . 'product` p 
				LEFT JOIN `' . _DB_PREFIX_ . 'product_lang` pl ON (p.`id_product` = pl.`id_product`) WHERE pl.`id_lang` = '.$cookie->id_lang;
        $all_products = Db::getInstance()->ExecuteS($sql);
        foreach ($all_products as &$product)
            $product['db_price'] = $product['price'];
        $all_products = Product::getProductsProperties(1, $all_products);

        $main_fields = $this->getConfig();
        $categories = Category::getHomeCategories(3, true);
        $i = 0;
        foreach ($categories as $temp => $datos) {
            $padre[$i]['id'] = $datos['id_category'];
            $padre[$i]['nombre'] = $datos['name'];
            $padre[$i]['link_rewrite'] = $datos['link_rewrite'];
            $i++;
        }
        ob_start();
        echo "<ul>";
        foreach ($categories as $temp => $datos) {
            echo "<li>";
            echo "<label onclick ='cargarSubcategorias(" . $datos['id_category'] . "," . $cookie->id_lang . ", 1)'>" . $datos['name'] . "</label>";
            echo "<select id='select_" . $datos['id_category'] . "'>";
            echo "<option value='0'>-</option>";
            echo "<option value='1'>+</option>";
            echo "</select>";
            echo "<input id='" . $datos['id_category'] . "' onblur='actualizarPrecioCategoria(" . $datos['id_category'] . ")'>";
            echo "<span class='porcentaje'>%</span>";
            echo "</li>";
        }
        echo "</ul>";
        echo "<div class='elementos'>";
        echo "<div id='subcategorias'><ul id='subCategoriaList'></ul></div>";
        echo "<div id='productos'><ul id='productoList'></ul></div>";
        echo "</div>";
        echo "<input type='hidden' name='idioma' value='" . $cookie->id_lang . "' id='idioma'>";
        echo "<input type='hidden' name='idUsuario' value='" . $cookie->id_employee . "' id='idUsuario'>";
        ?>




        <input type="hidden" name="mu_doupdate" value="go">
        <label><?php echo $this->l('Aplicar Descuento o Incremento en todos los articulos');?> </label>
        <select name="selectAll" id="selectAll">
            <option value="0">-</option>
            <option value="1">+</option>
        </select> 
        <input type="text" name=updateAll" onBlur="actualizarTodo()" id="updateAll" />
        <span class="porcentaje">%</span>

       
                <?php
                $this->_html .= ob_get_clean();

                $this->_html .= ' 
				
		     	
			</form>
		</fieldset>';



                return $this->_html;
            }

        }
        ?>
